(->tmp-file parent prefix suffix)Create a new temporary file in the parent directory.
Create a new temporary file in the parent directory.
(delete! f)Recursively delete a directory or a single file.
Recursively delete a directory or a single file.
(unix-path f)Returns a string representation of path with unix separators ('/') instead of the system-dependent separators (which is backslash on Windows).
Returns a string representation of path with unix separators ('/')
instead of the system-dependent separators (which is backslash on Windows).cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |