Handling the meta-model of OOXML documents. See: http://officeopenxml.com/anatomyofOOXML.php
Handling the meta-model of OOXML documents. See: http://officeopenxml.com/anatomyofOOXML.php
(template-model->writers-map template data function fragments)Evaluates a prepared template and returns a {path writer-fn} map that can be used to write the zip stream.
Evaluates a prepared template and returns a {path writer-fn} map that can be used to write the zip stream.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |